@@ -1,18 +1,22 @@
 """
+Contains Lino's core functionalities.
 
 .. autosummary::
    :toctree:
 
     actions
     actors
-    auth
     boundaction
+    callbacks
     choicelists
     constants
+    dashboard
     dbtables
     dbutils
     ddh
+    diff
     elems
+    exceptions
     fields
     frames
     inject
@@ -22,20 +26,22 @@
     menus
     merge
     model
-    perms
+    permissions
     plugin
     renderer
     requests
+    roles
     signals
-    site_def
+    site
     store
     tables
     tablerequest
     urls
+    userprefs
+    user_types
     utils
     views
-    web
     workflows
-
+    auth
 
 """
