@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """This defines the :class:`Action` class and the :func:`action`
@@ -34,7 +34,7 @@ from .utils import traverse_ddh_fklist
 from .requests import InstanceAction
 
 def discover_choosers():
-    logger.debug("Discovering choosers for model fields...")
+    logger.debug("Discovering choosers for database fields...")
     # ~ logger.debug("Instantiate model reports...")
     for model in get_models():
         # ~ n = 0
@@ -856,7 +856,7 @@ class ShowInsert(TableAction):
     else:
         # button_text = u"❏"  # 274F Lower right drop-shadowed white square
         # button_text = u"⊞"  # 229e SQUARED PLUS
-        button_text = u"⊕"  # 2295 circled plus
+        button_text = "⊕"  # 2295 circled plus
 
     ui5_icon_name = "sap-icon://add"
     help_text = _("Insert a new record")
@@ -1092,6 +1092,7 @@ class SubmitInsert(CreateRow):
         # is going to be closed (this disturbs at least in ticket
         # #219)
         ar.requesting_panel = None
+        # print("20201230 SubmitInsert.run_from_ui", ar)
         if ar.actor.handle_uploaded_files is not None and len(ar.request.FILES.getlist("file")) > 1:
             # Multiple uploads possible, note plural method names.
             elems = ar.create_instances_from_request(**kwargs)
@@ -1203,7 +1204,7 @@ class DeleteSelected(MultipleRowAction):
     if True:  # settings.SITE.use_silk_icons:
         icon_name = 'delete'
     else:
-        button_text = u"⊖"  # 2296 CIRCLED MINUS
+        button_text = "⊖"  # 2296 CIRCLED MINUS
         # button_text = u"⊟"  # 229F SQUARED MINUS
 
     ui5_icon_name = 'sap-icon://less'
@@ -1235,12 +1236,13 @@ class DeleteSelected(MultipleRowAction):
         cascaded_objects = {}
         kernel = settings.SITE.kernel
         for obj in ar.selected_rows:
+            # print(20201229, "selected:", obj)
             for m, fk in traverse_ddh_fklist(obj.__class__):
-                # print(20200724, fk)
                 if fk.name in m.allow_cascaded_delete:
                     qs = m.objects.filter(**{fk.name:obj})
                     n = qs.count()
                     if n:
+                        # print(20201229, n, fk, m, qs)
                         if m in cascaded_objects:
                             cascaded_objects[m] += n
                         else:
