@@ -50,7 +50,7 @@ WINDOW_TYPE_TABLE = "t"
 WINDOW_TYPE_DETAIL = "d"
 WINDOW_TYPE_INSERT = "i"
 WINDOW_TYPE_CARDS = "c"
-WINDOW_TYPE_PV = "p"
+WINDOW_TYPE_PARAMS = "p"
 
 
 #~ URL_PARAM_EUSER = 'euser'
