@@ -10,6 +10,7 @@ import logging ; logger = logging.getLogger(__name__)
 import datetime
 
 from django.conf import settings
+from django.core.exceptions import FieldDoesNotExist
 from django.db.models.fields import NOT_PROVIDED
 from django.utils.translation import ugettext_lazy as _
 
@@ -427,7 +428,7 @@ class Table(AbstractTable):
                         raise Exception(
                             "Unsupported master_key {0}.{1} ({2})".format(
                                 self, fk, fk.__class__))
-                except models.FieldDoesNotExist:
+                except FieldDoesNotExist:
                     for vf in self.model._meta.private_fields:
                         if vf.name == self.master_key:
                             fk = vf
@@ -465,7 +466,7 @@ class Table(AbstractTable):
                 raise Exception("%s.order_by is %r (must be a list or tuple)" %
                                 (self, self.order_by))
             if False:
-                # good idea, but doesn't yet work for foreign fields,
+                # good idea, but doesn't yet work for remote fields,
                 # e.g. order_by = ['content_type__app_label']
                 for fieldname in self.order_by:
                     if fieldname.startswith('-'):
@@ -475,7 +476,7 @@ class Table(AbstractTable):
                             fieldname)
                         assert direct
                         assert not m2m
-                    except models.FieldDoesNotExist:
+                    except FieldDoesNotExist:
                         raise Exception("Unknown fieldname %r in %s.order_by" %
                                         (fieldname, self))
 
@@ -639,7 +640,8 @@ class Table(AbstractTable):
                 qs = qs.extra(**extra)
             order_by = ar.order_by or self.order_by
             if order_by:
-                # logger.info("20120122 order_by %s",order_by)
+                # if str(ar.actor) == "sheets.BalanceEntriesByReport":
+                #     print("20120122 order_by {}".format(order_by))
                 qs = qs.order_by(*order_by)
             if self.debug_sql:
                 logger.info("%s %s", self.debug_sql, qs.query)
