@@ -609,12 +609,12 @@ class VirtualField(FakeField):
     #~ def get_choices(self): return self.return_type.choices
     #~ choices = property(get_choices)
 
-    def set_value_in_object(self, request, obj, value):
+    def set_value_in_object(self, ar, obj, value):
         """
         Stores the specified `value` in the specified model instance
         `obj`.  `request` may be `None`.
 
-        Note that any implementation must also return `obj`, and
+        Note that any implementation must return `obj`, and
         callers must be ready to get another instance.  This special
         behaviour is needed to implement
         :class:`lino.utils.mti.EnableChild`.
@@ -624,7 +624,6 @@ class VirtualField(FakeField):
         #     raise NotImplementedError("Cannot write %s to field %s" %
         #                               (value, self))
 
-    #~ def value_from_object(self,request,obj):
     def value_from_object(self, obj, ar=None):
         """
         Return the value of this field in the specified model instance
@@ -1144,11 +1143,12 @@ class TableRow(object):
         <lino.core.menus.Menu.add_instance_action>`.
 
         Usage example: :class:`courses.Course
-        <lino_xl.lib.courses.models.Course>` overrides this to return
-        the detail_action depending on the CourseArea.
+        <lino_xl.lib.courses.Course>` overrides this to return
+        the detail_action depending on the ActivityLayout.
 
         """
         a = getattr(self, '_detail_action', None)
+        # print("20201230 get_detail_action", ar.actor, ar.actor.model, self.__class__)
         if a is None:
             if ar and ar.actor and ar.actor.model \
                and self.__class__ is ar.actor.model:
