@@ -1,31 +1,26 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2014 Luc Saffre
+# Copyright 2009-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
 """
-Defines the classes :class:`MenuItem`
+Defines the classes :class:`MenuItem` and :class:`Menu`
 """
 
-import logging
-logger = logging.getLogger(__name__)
+from builtins import object
+
+import logging ; logger = logging.getLogger(__name__)
 
 from django.conf import settings
-from django.db import models
 
-from atelier import rstgen
-from lino.core.dbutils import obj2str
+from lino.core.utils import obj2str
+from lino.core.actors import resolve_action
+from lino.core.boundaction import BoundAction
 
 
-from lino.core import actors
-from lino.core import actions
-from lino.utils.xmlgen import html as xghtml
-E = xghtml.E
-
-
-class MenuItem:
-
+class MenuItem(object):
     """
-    Represents a menu item
+    A menu item. Note that this is subclassed by :class:`Menu`: a menu
+    is also a menu item.
     """
     HOTKEY_MARKER = '~'
 
@@ -37,7 +32,7 @@ class MenuItem:
                  action=None,
                  #~ can_view=None,
                  hotkey=None,
-                 params={},
+                 params=None,
                  help_text=None,
                  #~ request=None,
                  instance=None,
@@ -47,14 +42,14 @@ class MenuItem:
             pass
             #~ if instance is not None:
                 #~ action = instance.get_default_table().default_action
-        elif not isinstance(action, actors.BoundAction):
+        elif not isinstance(action, BoundAction):
             raise Exception("20121003 not a BoundAction: %r" % action)
         if instance is not None:
             if action is None:
                 raise Exception("20130610")
             instance._detail_action = action
         self.bound_action = action
-        self.params = params
+        self.params = params or {}
         self.href = href
         #~ self.request = request
         self.instance = instance
@@ -63,7 +58,7 @@ class MenuItem:
 
         if label is None:
             if instance is not None:
-                label = unicode(instance)
+                label = str(instance)
             elif action is not None:
                 label = action.get_button_label()
 
@@ -73,8 +68,8 @@ class MenuItem:
         self.enabled = enabled
         self.hotkey = hotkey
 
-        if label:
-            label = label.replace('~', '')
+        # if label:
+        #     label = label.replace('~', '')
         self.label = label
 
         #~ if self.label is None:
@@ -92,6 +87,12 @@ class MenuItem:
     def walk_items(self):
         yield self
 
+    def find_item(self, spec):
+        bound_action = resolve_action(spec)
+        for mi in self.walk_items():
+            if mi.bound_action == bound_action:
+                return mi
+
     def __repr__(self):
         s = self.__class__.__name__ + "("
         attrs = []
@@ -131,87 +132,32 @@ class MenuItem:
             return s + self.name
         return s
 
-    def as_bootstrap_html(self, renderer, request, level=None):
-        if self.bound_action:
-            assert renderer is not None
-            sr = self.bound_action.actor.request(
-                action=self.bound_action,
-                user=request.user, subst_user=request.subst_user,
-                requesting_panel=request.requesting_panel,
-                renderer=renderer, **self.params)
-
-            url = sr.get_request_url()
-        else:
-            url = self.href
-        assert self.label is not None
-        if url is None:
-            return E.p()  # spacer
-        return E.li(E.a(self.label, href=url, tabindex="-1"))
-
     def as_rst(self, ar, level=None):
         """
         Render this menu item as an rst string.
         Currently used only for writing test cases.
         """
-        #~ if self.bound_action:
-            #~ sr = self.bound_action.actor.request(
-                #~ action=self.bound_action,
-                #~ user=request.user,subst_user=request.subst_user,
-                #~ requesting_panel=request.requesting_panel,
-                #~ renderer=ui.plain_renderer,**self.params)
-          #~
-            #~ url = sr.get_request_url()
-        #~ else:
-            #~ url = self.href
-        #~ assert self.label is not None
-        #~ if url is None:
-            # ~ return E.p() # spacer
-        #~ return E.li(E.a(self.label,href=url,tabindex="-1"))
-        return unicode(self.label)
+        return str(self.label)
 
+    # def has_items(menu):
+    #     for i in menu.items:
+    #         if i.label is None:
+    #             raise Exception("20130907 %r has no label" % i)
+    #         if not i.label.startswith('-'):
+    #             return True
+    #     return False
 
-def has_items(menu):
-    for i in menu.items:
-        if i.label is None:
-            raise Exception("20130907 %r has no label" % i)
-        if not i.label.startswith('-'):
-            return True
-    return False
+    def openui5Render(self):
+
+        ar = self.bound_action.request(**self.params)
+        js = settings.SITE.kernel.default_renderer.request_handler(ar)
+        return js
 
 
 def create_item(spec, action=None, help_text=None, **kw):
     """
     """
-    givenspec = spec
-    if isinstance(spec, basestring):
-        spec = settings.SITE.modules.resolve(spec)
-        #~ if a is None:
-            #~ raise Exception("Could not resolve action specifier %r" % spec)
-    if isinstance(spec, actors.BoundAction):
-        a = spec
-    else:
-        if isinstance(spec, type) and issubclass(spec, models.Model):
-            spec = spec.get_default_table()
-            assert spec is not None
-
-        if isinstance(spec, type) and issubclass(spec, actors.Actor):
-            if action:
-                a = spec.get_url_action(action)
-                #~ print 20121210, a
-                if a is None:
-                    raise Exception("add_action(%r,%r,%r) found None" %
-                                    (spec, action, kw))
-            else:
-                a = spec.default_action
-                if a is None:
-                    raise Exception("%r default_action is None?!" % spec)
-        else:
-            raise Exception("Action spec %r returned invalid object %r" %
-                            (givenspec, spec))
-
-    #~ if kw.has_key('params'):
-        #~ if a.actor.__name__ == 'Contacts':
-          #~ raise Exception("20120103")
+    a = resolve_action(spec, action)
     if help_text is None:
         if a == a.actor.default_action:
             help_text = a.actor.help_text or a.action.help_text
@@ -224,9 +170,8 @@ def create_item(spec, action=None, help_text=None, **kw):
 
 
 class Menu(MenuItem):
-
     """
-    Represents a menu. A menu is conceptually a :class:`MenuItem` 
+    Represents a menu. A menu is conceptually a :class:`MenuItem`
     which contains other menu items.
     """
 
@@ -234,31 +179,33 @@ class Menu(MenuItem):
     """
     If set to True, avoid lonely menu items by lifting them up one level.
     This is not done for top-level menus
-    
+
     For example the following menu::
-        
+
         Foo           Bar         Baz
         |Foobar       |BarBaz
          |Copy
          |Paste
         |FooBarBaz
          | Insert
-         
+
     would become::
-         
+
         Foo           BarBaz        Baz
-        |Foobar       
+        |Foobar
          |Copy
          |Paste
         |Insert
-         
-    
+
+
     """
 
-    def __init__(self, user_profile, name, label=None, parent=None, **kw):
+    def __init__(self, user_type, name, label=None, parent=None, **kw):
         MenuItem.__init__(self, name, label, **kw)
         self.parent = parent
-        self.user_profile = user_profile
+        if settings.SITE.user_types_module:
+            assert user_type is not None
+        self.user_type = user_type
         self.clear()
 
     def clear(self):
@@ -267,9 +214,15 @@ class Menu(MenuItem):
 
     def compress(self):
         """
-        Dynamically removes empty menu entries.
+        Dynamically removes empty menu entries and useless separators.
         Collapses menu with only one item into their parent.
         """
+        while len(self.items) and self.items[-1].label.startswith('-'):
+            del self.items[-1]
+
+        while len(self.items) and self.items[0].label.startswith('-'):
+            del self.items[0]
+
         for mi in self.items:
             mi.compress()
 
@@ -277,7 +230,8 @@ class Menu(MenuItem):
 
         for mi in self.items:
             if isinstance(mi, Menu):
-                if has_items(mi):
+                # if mi.has_items():
+                if len(mi.items):
                     if not self.avoid_lonely_items:
                         newitems.append(mi)
                     elif len(mi.items) == 1:
@@ -297,28 +251,23 @@ class Menu(MenuItem):
         mi = create_item(*args, **kw)
         return self.add_item_instance(mi)
 
-    #~ def add_action_(self,action,**kw):
-        #~ return self.add_item_instance(MenuItem(self,action,**kw))
-
-    #~ def add_item(self,**kw):
-        #~ return self.add_item_instance(Action(self,**kw))
-
-    #~ def add_request_action(self,ar,**kw):
-        #~ kw.update(request=ar)
-        #~ return self.add_item_instance(MenuItem(self,ar.action,**kw))
-
     def add_instance_action(self, obj, **kw):
         """
-        Add an action which displays the given object (a Django model instance)
-        in a detail form for editing.
-        Used e.g. for the SiteConfig object.
+        Add an action which displays the given database object instance in
+        a detail form for editing.
+
+        Used e.g. for the :menuselection`Configure --> System --> Site
+        configuration` command.  Or for the :guilabel:`[My settings]`
+        quicklink in :ref:`care`.
         """
         kw.update(instance=obj)
-        da = kw.get('action', None)
-        if da is None:
-            da = obj.get_default_table().detail_action
-            kw.update(action=da)
-        #~ obj._detail_action = da
+        ba = kw.get('action', None)
+        if ba is None:
+            ba = obj.get_default_table().detail_action
+            kw.update(action=ba)
+        # elif isinstance(ba, str):
+        #     ba = obj.get_default_table().get_action_by_name(ba)
+        #     kw.update(action=ba)
         return self.add_item_instance(MenuItem(**kw))
 
     def add_item(self, name, label, **kw):
@@ -330,7 +279,7 @@ class Menu(MenuItem):
 
     def add_menu(self, name, label, **kw):
         return self.add_item_instance(Menu(
-            self.user_profile, name, label, self, **kw))
+            self.user_type, name, label, self, **kw))
 
     def get_item(self, name):
         return self.items_dict[name]
@@ -351,10 +300,11 @@ class Menu(MenuItem):
         assert isinstance(mi, MenuItem)
         mi.parent = self
         if mi.bound_action is not None:
-            #~ if not mi.bound_action.actor.get_view_permission(self.user):
-            if not mi.bound_action.get_view_permission(self.user_profile):
+            if mi.bound_action.actor.is_abstract():
                 return
-            #~ logger.info("20130129 _add_item %s for %s",mi.label,self.user_profile)
+            if not mi.bound_action.get_view_permission(self.user_type):
+                return
+            #~ logger.info("20130129 _add_item %s for %s",mi.label,self.user_type)
         if mi.name is not None:
             old = self.items_dict.get(mi.name)
             if old is not None:
@@ -376,81 +326,17 @@ class Menu(MenuItem):
             for i in mi.walk_items():
                 yield i
 
-    #~ def unused_sort_items(self,front=None,back=None):
-        #~ new_items = []
-        #~ if front:
-            #~ for name in front.split():
-                #~ new_items.append(self.findItem(name))
-        #~ back_items = []
-        #~ if back:
-            #~ for name in back.split():
-                #~ back_items.append(self.findItem(name))
-        #~ for i in self.get_items():
-            #~ if not i in new_items + back_items:
-                #~ new_items.append(i)
-        #~ self.items = new_items + back_items
-        #~ self.items_dict = {}
-        #~ for i in self.items:
-            #~ self.items_dict[i.name] = i
-
-    def as_bootstrap_html(self, renderer, request, level=1):
-        items = [mi.as_bootstrap_html(renderer, request, level + 1)
-                 for mi in self.items]
-        #~ print 20120901, items
-        if level == 1:
-            return E.ul(*items, class_='nav navbar-nav')
-        if self.label is None:
-            raise Exception("%s has no label" % self)
-        if level == 2:
-            cl = 'dropdown'
-            menu_title = E.a(
-                unicode(self.label), E.b(' ', class_="caret"), href="#",
-                class_='dropdown-toggle', data_toggle="dropdown")
-        elif level == 3:
-            menu_title = E.a(unicode(self.label), href="#")
-            cl = 'dropdown-submenu'
-        else:
-            raise Exception("Menu with more than three levels")
-        return E.li(
-            menu_title,
-            E.ul(*items, class_='dropdown-menu'),
-            class_=cl)
-
-    def as_rst(self, ar, level=1):
-        """
-        Render this menu as an rst string.
-        Currently used only for writing test cases.
-        """
-        has_submenus = False
-        for i in self.items:
-            if isinstance(i, Menu):
-                has_submenus = True
-        items = [mi.as_rst(ar, level + 1) for mi in self.items]
-        if has_submenus:
-            s = rstgen.ul(items).strip() + '\n'
-            if self.label is not None:
-                s = unicode(self.label) + ' :\n\n' + s
-        else:
-            s = ', '.join(items)
-            if self.label is not None:
-                s = unicode(self.label) + ' : ' + s
-        return s
-
 
 class Toolbar(Menu):
-
     """
-    A Toolbar is a top-level :class:`Menu`.
+    A top-level menu.
     """
     pass
 
 
-def find_menu_item(spec):
-    from django.conf import settings
-    from lino import dd
-    profile = dd.modules.users.UserProfiles.get_by_value('900')
-    menu = settings.SITE.get_site_menu(settings.SITE.ui, profile)
-    for mi in menu.walk_items():
-        if mi.bound_action == spec:
-            return mi
-    return None
+def find_menu_item(bound_action):
+    from lino.api import rt
+    user_type = rt.models.users.UserTypes.get_by_value('900')
+    return user_type.find_menu_item(bound_action)
+    # menu = settings.SITE.get_site_menu(settings.SITE.kernel, user_type)
+    # return menu.find_item(bound_action)
