@@ -48,14 +48,11 @@ class TableRequest(ActionRequest):
     <lino.core.tables.AbstractTable>`.
 
     """
-
     master = None
-
     extra = None
     title = None
     filter = None
     # known_values = None
-
     limit = None
     offset = None
 
@@ -388,8 +385,7 @@ class TableRequest(ActionRequest):
                         and (master is ContentType or master._meta.abstract)
                         and mt is not None):
                     try:
-                        master = ContentType.objects.get(
-                            pk=mt).model_class()
+                        master = ContentType.objects.get(pk=mt).model_class()
                     except ContentType.DoesNotExist:
                         pass
                         # master is None
@@ -439,7 +435,7 @@ class TableRequest(ActionRequest):
                   header_links=False, hide_sums=None):
         """
         Render this table into an existing :class:`etgen.html.Table`
-        instance.  This is central method is used by all Lino
+        instance.  This central method is used by all Lino
         renderers.
 
         Arguments:
