@@ -1,16 +1,7 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-""".. management_command:: diag
-
-Writes a diagnostic status report about this Site.
-
-This is a command-line shortcut for calling
-:meth:`lino.core.site.Site.diagnostic_report_rst`.
-
-"""
-
 from django.core.management.base import BaseCommand
 from django.conf import settings
 
