@@ -1,10 +1,6 @@
 # Copyright 2015-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-"""
-Database models for `lino.modlib.checkdata`.
-
-"""
 
 from builtins import object
 from collections import OrderedDict
@@ -108,39 +104,15 @@ class FixProblemsByController(UpdateProblemsByController):
 
 
 class Problem(Controllable, UserAuthored):
-    """Represents a detected data problem.
-
-    Database objects of this model are considered temporary data which
-    may be updated automatically without user interaction.
-
-    .. attribute:: checker
-
-       The :class:`Checker
-       <lino.modlib.checkdata.choicelists.Checker>` which reported
-       this problem.
-
-    .. attribute:: message
-
-       The message text. This is a concatenation of all messages that
-       were yeld by the :attr:`checker`.
-
-    .. attribute:: user
-
-       The :class:`user <lino.modlib.users.models.User>` reponsible
-       for fixing this problem.
-
-       This field is being filled by the :meth:`get_responsible_user
-       <lino.modlib.checkdata.choicelists.Checker.get_responsible_user>`
-       method of the :attr:`checker`.
-
-    """
     class Meta(object):
         app_label = 'checkdata'
         verbose_name = _("Data problem")
         verbose_name_plural = _("Data problems")
         ordering = ['owner_type', 'owner_id', 'checker']
 
+    controller_is_optional = False
     allow_merge_action = False
+    allow_cascaded_delete = 'owner'
 
     # problem_type = ProblemTypes.field()
     checker = Checkers.field(verbose_name=_("Checker"))
@@ -166,7 +138,6 @@ class Problem(Controllable, UserAuthored):
     def get_simple_parameters(cls):
         for p in super(Problem, cls).get_simple_parameters():
             yield p
-        # yield 'user'
         yield 'checker'
 
 dd.update_field(Problem, 'user', verbose_name=_("Responsible"))
@@ -177,7 +148,6 @@ Problem.update_controller_field(verbose_name = _('Database object'))
 
 
 class Problems(dd.Table):
-    "The base table for :class:`Problem` objects."
     model = 'checkdata.Problem'
     column_names = "user owner message #fixable checker *"
     auto_fit_column_widths = True
@@ -319,12 +289,17 @@ def get_checkable_models(*args):
     return checkable_models
 
 
-def check_data(args=[], fix=True):
+def check_data(args=[], fix=True, prune=False):
     """Called by :manage:`checkdata`. See there."""
     Problem = rt.models.checkdata.Problem
     mc = get_checkable_models(*args)
     if len(mc) == 0 and len(args) > 0:
         raise Exception("No checker matches {0}".format(args))
+    if prune:
+        qs = Problem.objects.all()
+        msg = "Prune {} existing messages...".format(qs.count())
+        dd.logger.info(msg)
+
     final_sums = [0, 0, 0]
     with translation.override('en'):
         for m, checkers in mc.items():
