@@ -137,13 +137,15 @@ class AdminIndex(View):
         return http.HttpResponse(renderer.html_page(request, **kw))
 
 def test_version_mismatch(request):
-    if not environ.get("PYCHARM_HOSTED", False) and request.GET.get(constants.URL_PARAM_LINO_VERSION) is not None and \
-                       float(request.GET.get(constants.URL_PARAM_LINO_VERSION)) != settings.SITE.kernel.code_mtime:
-        return dict(alert=_("Version mismatch"),
-                    message=_("Your browser is using a previous version of the site, press OK to reload the site"),
-                    alert_eval_js="window.location.reload(true);")
-    else:
+    if environ.get("PYCHARM_HOSTED", False):
         return {}
+    lv = request.GET.get(constants.URL_PARAM_LINO_VERSION)
+    if lv is None or float(lv) == settings.SITE.kernel.code_mtime:
+        return {}
+    # print("20201217", lv, settings.SITE.kernel.code_mtime)
+    return dict(alert=_("Version mismatch"),
+                message=_("Your browser is using a previous version of the site, press OK to reload the site"),
+                alert_eval_js="window.location.reload(true);")
 
 
 
@@ -361,6 +363,7 @@ class ApiElement(View):
 
     @method_decorator(ensure_csrf_cookie)
     def get(self, request, app_label=None, actor=None, pk=None):
+        # this is also used by the react front end
         ui = settings.SITE.kernel
         rpt = requested_actor(app_label, actor)
         # if not rpt.get_view_permission(request.user.user_type):
@@ -385,14 +388,23 @@ class ApiElement(View):
             # print(
             #     "20170116 views.ApiElement.get", ba,
             #     ar.action_param_values)
-            elem = ar.selected_rows[0]
+            if len(ar.selected_rows):
+                elem = ar.selected_rows[0]
+            else:
+                raise http.Http404("No permission to see {} {}.".format(rpt, action_name))
         else:
             ar = ba.request(request=request)
             elem = None
 
-        ar.renderer = ui.extjs_renderer
+        # ar.renderer = ui.extjs_renderer
+        ar.renderer = ui.default_renderer
         ah = ar.ah
 
+        if not ar.get_permission():
+            msg = "No permission to run {}".format(ar)
+            # raise Exception(msg)
+            raise PermissionDenied(msg)
+
         fmt = request.GET.get(
             constants.URL_PARAM_FORMAT, ba.action.default_format)
         if ba.action.opens_a_window:
@@ -419,9 +431,9 @@ class ApiElement(View):
                 after_show.update(active_tab=tab)
 
             return http.HttpResponse(
-                ui.extjs_renderer.html_page(
+                ar.renderer.html_page(
                     request, ba.action.label,
-                    on_ready=ui.extjs_renderer.action_call(
+                    on_ready=ar.renderer.action_call(
                         request, ba, after_show)))
 
         # if isinstance(ba.action, actions.RedirectAction):
