@@ -12,6 +12,23 @@ from lino.modlib.printing.choicelists import BuildMethods
 
 from inspect import isclass
 
+class PreviewPublication(dd.Action):
+    label = _("Preview")
+    select_rows = False
+
+    def run_from_ui(self, ar, **kw):
+        sr_selected = not isclass(self)
+        if sr_selected:
+            ar.success(open_url=self.publisher_url())
+        else:
+            ar.success(open_url=self.publisher_url(self, not sr_selected))
+
+    def get_view_permission(self, user_type):
+        if not dd.is_installed('publisher'):
+            return False
+        return super(PreviewPublication, self).get_view_permission(user_type)
+
+
 class Publishable(Printable):
     class Meta:
         abstract = True
@@ -21,15 +38,17 @@ class Publishable(Printable):
     publisher_template = "publisher/default.pub.html"
     publisher_list_template = "publisher/default_list.pub.html"
 
-    listTemplate = "publisher/default_list_item.html"
+    list_template = "publisher/default_list_item.html"
 
-    @dd.action(select_rows=False)
-    def preview_publication(self, ar):
-        sr_selected = not isclass(self)
-        if sr_selected:
-            ar.success(open_url=self.publisher_url())
-        else:
-            ar.success(open_url=self.publisher_url(self, not sr_selected))
+    preview_publication = PreviewPublication()
+
+    # @dd.action(select_rows=False)
+    # def preview_publication(self, ar):
+    #     sr_selected = not isclass(self)
+    #     if sr_selected:
+    #         ar.success(open_url=self.publisher_url())
+    #     else:
+    #         ar.success(open_url=self.publisher_url(self, not sr_selected))
 
     def publisher_url(self, list=False):
         if list:
