@@ -1,4 +1,4 @@
-# Copyright 2013-2014 Luc Saffre
+# Copyright 2013-2016 Luc Saffre
 # License: BSD (see file COPYING for details)
 
 """
@@ -7,8 +7,13 @@ This is used by tests/__init__.py
 
 from .settings import *
 
+
+class Site(Site):
+    languages = 'en de fr et nl pt-br es'
+    project_name = 'lino_std'
+
 SITE = Site(globals())
 """
-This Site instance will normally be replaced by an instance 
+This Site instance will normally be replaced by an instance
 in a local settings.py file
 """
