@@ -34,10 +34,6 @@ None None None
 None None None
 """
 
-from __future__ import unicode_literals
-from __future__ import print_function
-from builtins import object
-
 
 class Cycler(object):
 
