@@ -1,43 +1,49 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2014 by Luc Saffre.
+# Copyright 2009-2018 Rumma & Ko Ltd
 # License: BSD, see LICENSE for more details.
+# $ doctest lino/utils/format_date.py
 
-"""Date formatting functions
--------------------------
+"""
+This module provides miscellaneous date formatting functions.
 
-To run the Lino test suite on this module::
+There are different date formatting syntaxes:
 
-  $ python setup.py test -s tests.UtilsTests.test_format_date
+- `Babel <http://babel.pocoo.org/en/latest/dates.html#date-fields>`__
+- `Django <https://docs.djangoproject.com/en/2.0/ref/templates/builtins/#date>`__
 
-This module provides shortcuts to `python-babel`'s `date formatting
-functions <http://babel.pocoo.org/docs/dates/>`_.
 
+Note that if you ask just for English, then we change Babel's default
+localization (US) to UK because US date format is just silly for
+non-americans (no further comment).
+
+>>> from lino import startup
+>>> startup()
 >>> import datetime
->>> d = datetime.date(2013,8,26)
+>>> d = datetime.date(2013, 8, 26)
 >>> print(fds(d)) # short
-8/26/13
+26/08/2013
 >>> print(fdm(d)) # medium
-Aug 26, 2013
+26 Aug 2013
 >>> print(fdl(d)) # long
-August 26, 2013
+26 August 2013
 >>> print(fdf(d)) # full
-Monday, August 26, 2013
+Monday, 26 August 2013
 >>> print(fdmy(d)) # full
 August 2013
 
 
-The :func:`lino.core.format_date.format_date` function is a thin
-wrapper to the corresponding function in `babel.dates`, filling the
-`locale` parameter according to Django's current language (and doing
-the conversion).
+The :func:`format_date` function is a thin wrapper to the
+corresponding function in `babel.dates`, filling the `locale`
+parameter according to Django's current language (and doing the
+conversion).
 
 The major advantage over using `date_format` from
 `django.utils.formats` is that Babel offers a "full" format:
 
->>> today = datetime.date(2013,01,18)
+>>> today = datetime.date(2013,1,18)
 
 >>> print(format_date(today,'full'))
-Friday, January 18, 2013
+Friday, 18 January 2013
 
 >>> with translation.override('fr'):
 ...    print(format_date(today,'full'))
@@ -58,24 +64,43 @@ reede, 18. jaanuar 2013
 vrijdag 18 januari 2013
 
 
+>>> with translation.override('de'):
+...    print(fds(today))
+18.01.13
+>>> with translation.override('fr'):
+...    print(fds(today))
+18/01/2013
+>>> with translation.override('en_US'):
+...    print(fds(today))
+1/18/13
+>>> with translation.override('en'):
+...    print(fds(today))
+18/01/2013
+>>> with translation.override('en_UK'):
+...    print(fds(today))
+18/01/2013
+
+
 >>> print(fds('')) # empty string is tolerated
 <BLANKLINE>
 >>> print(fds('2014-10-12')) # not tolerated
 Traceback (most recent call last):
   ...
-Exception: Not a date: u'2014-10-12'
-
+Exception: Not a date: '2014-10-12'
 """
 
 from __future__ import unicode_literals, print_function
+from builtins import str
+import six
 
 import datetime
 from babel.dates import format_date as babel_format_date
 
+from django.conf import settings
 from django.utils import translation
 from django.template import defaultfilters
 
-from lino.core.site_def import to_locale
+from lino.core.site import to_locale
 from lino.utils import IncompleteDate
 
 
@@ -97,14 +122,26 @@ def fdmy(d):
 
 
 def format_date(d, format='medium'):
+    """Return the given date `d` formatted with `Babel's date formatting
+    <http://babel.edgewall.org/wiki/Documentation/dates.html>`_ and
+    using Django's current language.
+
+    """
     if not d:
         return ''
     if isinstance(d, IncompleteDate):
         d = d.as_date()
     if not isinstance(d, datetime.date):
-        raise Exception("Not a date: {0!r}".format(d))
-    return babel_format_date(
-        d, format=format, locale=to_locale(translation.get_language()))
+        if isinstance(d, six.text_type):
+            d = str(d)  # remove the "u" in Python 2
+        raise Exception(str("Not a date: {0!r}").format(d))
+    lng = translation.get_language()
+    if lng is None:  # occured during syncdb
+        lng = settings.SITE.languages[0].django_code
+    loc = to_locale(lng)
+    if loc == 'en':
+        loc = 'en_UK'  # I hate US date format
+    return babel_format_date(d, format=format, locale=loc)
 
 
 def fdf(d):
@@ -130,7 +167,20 @@ dtos = fds
 dtomy = fdmy  # backward compat
 
 
+# def day_and_month(d):
+#     # this is not used. see also lino_xl.lib.cal.utils.day_and_month
+#     return format_date(d, "dd. MMMM")
+
+
 def day_and_month(d):
-    return format_date(d, "dd. MMMM")
+    if d is None:
+        return "-"
+    return defaultfilters.date(d, 'd.m.')
+    # return d.strftime("%d.%m.")
 
+def day_and_weekday(d):
+    if d is None:
+        return "-"
+    return defaultfilters.date(d, 'D d.')
+    # return d.strftime("%a%d")
 
