@@ -1,23 +1,34 @@
 # -*- coding: utf-8 -*-
-# Copyright 2011-2014 Luc Saffre
+# Copyright 2011-2016 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-ur"""
+# How to test this document:
+#
+#  $ python setup.py test -s tests.UtilsTests.test_tidy
 
-Defines the :func:`html2xhtml` function which converts
-HTML to valid XHTML. It is far from being perfect but
-activaly being used in :mod:`lino.utils.appy_pod`.
+r"""Defines the :func:`html2xhtml` function which converts HTML to
+valid XHTML.
 
-This document is a part of the test suite.
+It uses Jason Stitt's `pytidylib
+<http://countergram.com/open-source/pytidylib/docs/index.html>`__
+module. This module requires the `HTML Tidy library
+<http://tidy.sourceforge.net/>`__ to be installed on the system::
 
-  $ python setup.py test -s tests.UtilsTests.test_tidy
+    $ sudo apt-get install tidy
+
+Some examples:
 
 >>> print(html2xhtml('''\
 ... <p>Hello,&nbsp;world!<br>Again I say: Hello,&nbsp;world!</p>
-... <img src="foo.org">''')) #doctest: +NORMALIZE_WHITESPACE
+... <img src="foo.org" alt="Foo">'''))
+... #doctest: +NORMALIZE_WHITESPACE -SKIP
 <p>Hello,&nbsp;world!<br />
 Again I say: Hello,&nbsp;world!</p>
-<img src="foo.org" alt="" />
+<img src="foo.org" alt="Foo" />
+
+Above test is currently skipped because tidylib output can slightly
+differ (``alt="Foo">`` versus ``alt="Foo" >``) depending on the
+installed version of tidylib.
 
 
 >>> html = '''\
@@ -42,7 +53,6 @@ before and reopended after a block element.
 <div><span class="c">oops</span></div>
 <span class="c">baz</span>bam
 
-
 >>> print(html2xhtml('''<strong><ul><em><li>Foo</li></em><li>Bar</li></ul></strong>'''))
 <ul>
 <li><strong><em>Foo</em></strong></li>
@@ -59,11 +69,11 @@ to "<p>foo</p><p>bar</p><p>baz</p>".
 <p>baz</p>
 
 
-  
+
 
 """
 
-from __future__ import print_function, unicode_literals
+# from __future__ import print_function, unicode_literals
 
 WRAP_BEFORE = """\
 <html>
@@ -77,6 +87,8 @@ try:
 
     from tidylib import tidy_fragment
 
+    # http://tidy.sourceforge.net/docs/quickref.html
+
     def html2xhtml(html, **options):
         options.update(doctype='omit')
         options.update(show_warnings=0)
@@ -84,7 +96,8 @@ try:
         # options.update(output_xml=1)
         options.update(output_xhtml=1)
         document, errors = tidy_fragment(html, options=options)
-        if errors:
+        if False:  # errors:
+            # LS 20190905 disabled error checking, see my blog
             #~ raise Exception(repr(errors))
             raise Exception("Errors while processing %s\n==========\n%s" %
                             (html, errors))
@@ -93,14 +106,20 @@ try:
         #     document = document[:-15]
         return document.strip()
 
+    HAS_TIDYLIB = True
+
 except OSError:
-    # happens on on readthedocs.org:
-    # OSError: Could not load libtidy using any of these names: libtidy,libtidy.so,libtidy-0.99.so.0,cygtidy-0-99-0,tidylib,libtidy.dylib,tidy
-    # we can simply ignore it since it is just for building the docs.
-    
-    from mytidylib import html2xhtml
-    #  TODO: emulate it well enough so that at least the test suite passes
-    
+    # happens on readthedocs.org and Travis CI: OSError: Could not
+    # load libtidy using any of these names:
+    # libtidy,libtidy.so,libtidy-0.99.so.0,cygtidy-0-99-0,tidylib,
+    # libtidy.dylib,tidy
+
+    # We can simply ignore it since it is just for building the docs.
+    from lino.utils.mytidylib import html2xhtml
+    # TODO: emulate it well enough so that at least the test suite passes
+
+    HAS_TIDYLIB = False
+
 
 def _test():
     import doctest
