@@ -1,15 +1,26 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2014 Luc Saffre
+# Copyright 2012-2017 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-"""Defines the fields :class:`LanguageField`, :class:`BabelCharField`
-and :class:`BabelTextField`, and the model mixin :class:`BabelNamed`.
+"""Defines the babel field classes (:class:`BabelCharField` and
+:class:`BabelTextField`) and the :class:`LanguageField` class.
 
-See usage example in :ref:`mldbc_tutorial`.
+**Babel fields** are fields which "generate" in the Django model a
+series of normal CharFields (or TextFields), one for each
+:attr:`lino.core.site.Site.language`.
+
+Example::
+
+  class Foo(models.Model):
+      name = BabelCharField(_("Foo"), max_length=200)
+      
+
+.. autosummary::
 
 """
 
 from __future__ import unicode_literals
+import six
 
 import logging
 logger = logging.getLogger(__name__)
@@ -18,7 +29,7 @@ from django.conf import settings
 from django.db import models
 
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import string_concat
+from django.utils.text import format_lazy
 
 from lino.core.fields import RichTextField
 
@@ -30,21 +41,28 @@ def contribute_to_class(field, cls, fieldclass, **kw):
     if cls._meta.abstract:
         return
     kw.update(blank=True)
+    if "__fake__" in repr(cls):
+        # Used to test if we're creating a migration, in that case we don't want to add new fields,
+        # As they're already detected during site startup.
+        return
     for lang in settings.SITE.BABEL_LANGS:
-        kw.update(verbose_name=string_concat(
+        kw.update(verbose_name=format_lazy(u"{}{}",
             field.verbose_name, ' (' + lang.django_code + ')'))
         newfield = fieldclass(**kw)
         #~ newfield._lino_babel_field = True
         # used by dbtools.get_data_elems
         newfield._lino_babel_field = field.name
         newfield._babel_language = lang
-        cls.add_to_class(field.name + '_' + lang.name, newfield)
+        cls.add_to_class(six.text_type(field.name + '_' + lang.name), newfield)
+        # we must convert the field name to six.text_type because lang.name is a newstr, and Django can raise a
+        # TypeError: unorderable types: str() and <type 'str'>
+        # when a model contains both Babelfields and fields with plain Py2 str names.
 
 
 class BabelCharField(models.CharField):
 
     """Define a variable number of `CharField` database fields, one for
-    each language of your :attr:`lino.core.site_def.Site.languages`.  See
+    each language of your :attr:`lino.core.site.Site.languages`.  See
     :ref:`mldbc`.
 
     """
@@ -70,17 +88,20 @@ class BabelTextField(RichTextField):
 
 
 class LanguageField(models.CharField):
-
     """A field that lets the user select a language from the available
-    babel languages.
+    :attr:`lino.core.site.Site.languages`.
+
+    See also :meth:`lino.core.model.Model.get_print_language`.
 
     """
 
     def __init__(self, *args, **kw):
         defaults = dict(
             verbose_name=_("Language"),
-            choices=iter(settings.SITE.LANGUAGE_CHOICES),
-            default=settings.SITE.get_default_language,
+            # choices=list(settings.SITE.LANGUAGE_CHOICES),
+            choices=settings.SITE.LANGUAGE_CHOICES,
+            blank=True,
+            # default=settings.SITE.get_default_language,
             #~ default=get_language,
             max_length=LANGUAGE_CODE_MAX_LENGTH,
         )
